users : Users — amici1

# `users` : Users

See also `lino_amici.lib.users`.

## Models

## Actors

- User types : (no docstring)

- My : Mixin for tables on `Authored` which sets the requesting user as default value for the `author` filter parameter.

- Users : (no docstring)

- Users : (no docstring)

- Users : (no docstring)

- My settings : (no docstring)

- Authorities : (no docstring)

- Authorities given : (no docstring)

- Authorities taken : (no docstring)

- User roles : (no docstring)

- User sessions : (no docstring)